@@ -16,6 +16,13 @@ timeVariation <- function(mydata,
                           auto.text = TRUE,
                           alpha = 0.4, ...)   {
 
+
+    #greyscale handling
+    if (length(cols) == 1 && cols == "greyscale") {
+        #strip only
+        current.strip <- trellis.par.get("strip.background")
+        trellis.par.set(list(strip.background = list(col = "white")))
+    }
    
     vars <- c("date", pollutant)
     
@@ -372,6 +379,11 @@ timeVariation <- function(mydata,
     names(output$data)[1:4] <- subsets
     names(output$plot)[1:4] <- subsets
     class(output) <- "openair"
+
+    #reset if greyscale
+    if (length(cols) == 1 && cols == "greyscale") 
+        trellis.par.set("strip.background", current.strip)
+
     invisible(output)
 }
 
